@@ -372,9 +372,9 @@ public class SVGWriter
     throws IOException
   {
     writer.write(writeNumber(coordinate.x) + " " + writeNumber(coordinate.y));
-    if (outputDimension >= 3 && ! Double.isNaN(coordinate.z)) {
+    if (outputDimension >= 3 && ! Double.isNaN(coordinate.getZ())) {
       writer.write(" ");
-      writer.write(writeNumber(coordinate.z));
+      writer.write(writeNumber(coordinate.getZ()));
     }
   }
 
